@@ -6,7 +6,9 @@
 
 style  "gtk-default-iso-8859-2" {
        fontset = "-*-helvetica-medium-r-normal--12-*-*-*-*-*-iso8859-1,\
-		  -*-helvetica-medium-r-normal--12-*-*-*-*-*-iso8859-2"
+                  -*-arial-medium-r-normal--12-*-*-*-*-*-iso8859-1,\
+		  -*-helvetica-medium-r-normal--12-*-*-*-*-*-iso8859-2,\
+		  -*-arial-medium-r-normal--12-*-*-*-*-*-iso8859-2,*-r-*"
 }
 class "GtkWidget" style "gtk-default-iso-8859-2"
 
